-- Only required if you have packer configured as `opt`
vim.cmd [[packadd packer.nvim]]

return require('packer').startup(function()
    use 'morhetz/gruvbox'

    -- Status line
    use {
        'hoob3rt/lualine.nvim',
        config = function ()
            require('lualine').setup{
                options = {
                    icons_enabled = true,
                    theme = 'gruvbox',
                    component_separators = {'', ''},
                    section_separators = {'', ''},
                    disabled_filetypes = {}
                },
                sections = {
                    lualine_a = {'mode'},
                    lualine_b = {'branch'},
                    lualine_c = {'filename'},
		    lualine_x = {
			    { 'diagnostics', sources = {"nvim_lsp"}, symbols = {error = ' ', warn = ' ', info = ' ', hint = ' '} },
			    'encoding',
			    'filetype'
		    },
                    lualine_y = {'progress'},
                    lualine_z = {'location'}
                },
                inactive_sections = {
                    lualine_a = {},
                    lualine_b = {},
                    lualine_c = {'filename'},
                    lualine_x = {'location'},
                    lualine_y = {},
                    lualine_z = {}
                },
                tabline = {},
                extensions = {}
            }
        end
    }

    use 'tpope/vim-fugitive'
    use 'mhinz/vim-signify'

    use 'tpope/vim-surround'
    use 'tpope/vim-repeat'

    use {
        'neovim/nvim-lspconfig',
        requires = {
            "hrsh7th/cmp-nvim-lsp"
        }
    }
    use {
        'hrsh7th/nvim-cmp',
        event = 'InsertEnter',
        config = [[require('completion')]],
        requires = {
            -- 'hrsh7th/vim-vsnip-integ',
            'hrsh7th/vim-vsnip',
            'rafamadriz/friendly-snippets',
        },
    }
    use {'hrsh7th/cmp-vsnip', after = 'nvim-cmp'}
    use {'hrsh7th/cmp-buffer', after = 'nvim-cmp'}
    use {'hrsh7th/cmp-path', after = 'nvim-cmp'}
    use {'hrsh7th/cmp-nvim-lsp', after = 'nvim-cmp'}
    use {'f3fora/cmp-spell', after = 'nvim-cmp'}


    use 'nvim-lua/popup.nvim'
    use {
        'nvim-telescope/telescope.nvim',
        requires = { {'nvim-lua/plenary.nvim'} }
    }

    use {
        'lervag/vimtex',
        config = [[require('config.vimtex')]],
    }

    --  Highlight on Yank 
    use 'machakann/vim-highlightedyank'
    --  Autoclose parenthesis
    use 'jiangmiao/auto-pairs'

    use 'kyazdani42/nvim-web-devicons'

end)
